@@ -32,13 +32,11 @@ OC.L10N.register(
     "Error" : "Fallu",
     "Saved" : "Guardóse",
     "TURN server protocols" : "Protocolos del sirvidor TURN",
-    "UDP and TCP" : "UDP y TCP",
-    "UDP only" : "Namái UDP",
-    "TCP only" : "Namái TCP",
     "Copy link" : "Copiar enllaz",
     "Waiting for others to join the call …" : "Esperando que los otros se xunan a la llamada...",
     "Show your screen" : "Amosar la to pantalla",
     "Stop screensharing" : "Parar compartición de pantalla",
+    "Settings" : "Settings",
     "Dismiss" : "Escartar",
     "Mute audio" : "Silenciar audiu",
     "Disable video" : "Deshabilitar videu",
@@ -53,29 +51,27 @@ OC.L10N.register(
     "Favorite" : "Marcar como favoritu",
     "Password protection" : "Password protection",
     "Enter a password" : "Introduz una contraseña",
+    "Save" : "Guardar",
+    "Edit" : "Editar",
+    "Password" : "Password",
+    "API token" : "Pase d'API",
+    "Login" : "Aniciu de sesión",
+    "Nickname" : "Nomatu",
+    "Client ID" : "ID de veceru",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
     "Loading" : "Cargando",
     "Groups" : "Grupos",
     "Circles" : "Círculos",
-    "Settings" : "Settings",
     "Password protect" : "Protexer con contraseña",
     "Close" : "Zarrar",
     "Reply" : "Rempuesta",
     "Remove" : "Desaniciar",
     "Today" : "Güei",
     "Yesterday" : "Ayeri",
-    "Enabled" : "Habilitar",
-    "Save" : "Guardar",
-    "Password" : "Password",
-    "API token" : "Pase d'API",
-    "Login" : "Aniciu de sesión",
-    "Nickname" : "Nomatu",
-    "Client ID" : "ID de veceru",
     "guest" : "invitáu",
     "No results" : "Ensin resultaos",
     "Add users or groups" : "Add users or groups",
-    "Edit" : "Editar",
     "Keyboard shortcuts" : "Atayos de tecláu",
     "Search" : "Search",
     "Grid view" : "Vista de rexella",
@@ -91,12 +87,10 @@ OC.L10N.register(
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "El sirvidor TURN úsase pa unviar al proxy el tráficu de los participantes darrera de tornafueos.",
     "Android app" : "Aplicación p'Android",
     "iOS app" : "Aplicación pa iOS",
-    "No other people in this call" : "Nun hai más xente nesta llamada",
-    "Your screen" : "La to pantalla",
-    "Contacts" : "Contautos",
-    "Guests" : "Convidaos",
+    "UDP and TCP" : "UDP y TCP",
+    "UDP only" : "Namái UDP",
+    "TCP only" : "Namái TCP",
     "Share link" : "Compartir enllaz",
-    "Cancel" : "Encaboxar",
-    "Submit" : "Unviar"
+    "Enabled" : "Habilitar"
 },
 "nplurals=2; plural=(n != 1);");
