@@ -41,15 +41,13 @@ OC.L10N.register(
     "STUN servers" : "Servidores STUN",
     "A STUN server is used to determine the public IP address of participants behind a router." : "Un servidor STUN se está usando para determinar la IP pública de los participantes que estén detrás de un ruteador. ",
     "TURN server protocols" : "Protocolos del servidor TURN",
-    "UDP and TCP" : "UDP y TCP",
-    "UDP only" : "UDP únicamente",
-    "TCP only" : "TCP únicamente",
     "Copy link" : "Copiar liga",
     "Waiting for others to join the call …" : "Esperando a que los demás se unan a la llamada ...",
     "You can invite others in the participant tab of the sidebar" : "Puedes invitar a otras personas en la pestaña de participante del menú lateral",
     "Share this link to invite others!" : "¡Comparte esta liga para invitar a otras personas!",
     "Show your screen" : "Mostrar tu pantalla",
     "Stop screensharing" : "Dejar de compartir la pantalla",
+    "Settings" : "Configuraciones ",
     "Dismiss" : "Descartar",
     "Mute audio" : "Silenciar audio",
     "Disable video" : "Deshabilitar video",
@@ -67,25 +65,24 @@ OC.L10N.register(
     "Favorite" : "Hacer favorito",
     "Password protection" : "Protección con contraseña",
     "Enter a password" : "Ingresa una contraseña",
+    "Save" : "Guardar",
+    "Edit" : "Editar",
+    "Password" : "Contraseña",
+    "API token" : "Ficha del API",
+    "Login" : "Iniciar sesión",
+    "Nickname" : "Apodo",
+    "Client ID" : "ID del cliente",
     "Remove from favorites" : "Eliminar de favoritos",
     "Add to favorites" : "Agregar a tus favoritos",
     "Loading" : "Cargando",
     "Groups" : "Grupos",
     "Circles" : "Círculos",
-    "Settings" : "Configuraciones ",
     "Password protect" : "Proteger con contraseña",
     "Close" : "Cerrar",
     "Reply" : "Responder",
     "Remove" : "Eliminar",
     "Today" : "Hoy",
     "Yesterday" : "Ayer",
-    "Enabled" : "Habilitado",
-    "Save" : "Guardar",
-    "Password" : "Contraseña",
-    "API token" : "Ficha del API",
-    "Login" : "Iniciar sesión",
-    "Nickname" : "Apodo",
-    "Client ID" : "ID del cliente",
     "moderator" : "moderador",
     "Demote from moderator" : "Degradar de moderador",
     "Promote to moderator" : "Promover a moderador",
@@ -94,7 +91,6 @@ OC.L10N.register(
     "Add users or groups" : "Agregar usuarios o grupos",
     "Participants" : "Participantes",
     "Chat" : "Chat",
-    "Edit" : "Editar",
     "Keyboard shortcuts" : "Atajos del teclado",
     "Search" : "Buscar",
     "Grid view" : "Vista de cuadrícula",
@@ -112,15 +108,10 @@ OC.L10N.register(
     "Android app" : "Aplicación android",
     "iOS app" : "Aplicación iOS",
     "{user} wants to talk with you" : "{user} quiere hablar contigo",
-    "No other people in this call" : "No hay más personas en esta llamada",
-    "Your screen" : "Tu pantalla",
-    "Contacts" : "Contactos",
-    "[Unknown user name]" : "[Nombre de usuario desconocido]",
-    "Guests" : "Invitados",
+    "UDP and TCP" : "UDP y TCP",
+    "UDP only" : "UDP únicamente",
+    "TCP only" : "TCP únicamente",
     "Share link" : "Compartir liga",
-    "Please enter the password for this call" : "Por favor ingresa la contraseña para esta llamada",
-    "Password required" : "Contraseña requerida",
-    "Cancel" : "Cancelar",
-    "Submit" : "Enviar"
+    "Enabled" : "Habilitado"
 },
 "nplurals=2; plural=(n != 1);");
