@@ -14,6 +14,7 @@ OC.L10N.register(
     "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Du ble invitert til et <strong>samtale</strong>, eller fikk et <strong>anrop</strong>",
     "Talk" : "Samtale",
     "Guest" : "Gjest",
+    "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "Velkommen til Nextcloud Talk!\nI denne samtalen vil vi informere deg om Nextcloud Talks nye funksjoner.",
     "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft Edge og Safari kan nå bli benyttet for å delta i lyd- og videosamtaler",
     "- You can now mention guests in the chat" : "- Du kan nå nevne gjester i chat'n",
     "Talk updates ✅" : "Talk oppdateringer ✅",
@@ -328,7 +329,6 @@ OC.L10N.register(
     "General settings" : "Generelle innstillinger",
     "All messages" : "Alle meldinger",
     "Off" : "ett kvarter",
-    "E-mail of the user" : "Brukerens epostadresse",
     "Language" : "Språk",
     "Country" : "Land",
     "Status" : "Status",
@@ -370,11 +370,9 @@ OC.L10N.register(
     "Share a single window" : "Del et enkelt vindu",
     "Show your screen" : "Vis din skjerm",
     "Stop screensharing" : "Stopp skjermdeling",
-    "Lower hand" : "Senk hånden",
     "More actions" : "Flere handlinger",
     "Settings" : "Innstillinger",
     "Dismiss" : "Forkast",
-    "Raise hand" : "Løft hånden",
     "No audio" : "Ingen lyd",
     "Mute audio (m)" : "Slå av lyd (m)",
     "Unmute audio (m)" : "Slå på lyd (m)",
@@ -512,6 +510,9 @@ OC.L10N.register(
     "Projects" : "Prosjekter",
     "Share link" : "Del lenke",
     "New in Talk 10" : "Nytt i Talk 10",
-    "Enabled" : "Aktivert"
+    "E-mail of the user" : "Brukerens epostadresse",
+    "Enabled" : "Aktivert",
+    "Lower hand" : "Senk hånden",
+    "Raise hand" : "Løft hånden"
 },
 "nplurals=2; plural=(n != 1);");
