@@ -11,6 +11,7 @@ OC.L10N.register(
     "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Avètz assistit a una sonada amb {user1}, {user2}, {user3}, {user4} e {user5}",
     "_%n other_::_%n others_" : ["%n autre","%n autres"],
     "{actor} invited you to {call}" : "{actor} vos a convidat a {call}",
+    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Sètz convidat a una <strong>conversacion</strong> o avètz agut una <strong>sonada</strong>",
     "Talk" : "Talk",
     "Guest" : "Convidat",
     "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "La benvenguda a Nextcloud Talk !\nDins aquesta conversacion vos informarem a prepaus de las foncionalitats novèlas dins Nextcloud Talk.",
@@ -46,10 +47,16 @@ OC.L10N.register(
     "{actor} limited the conversation to the current participants" : "{actor} a limitat la conversacion als participants actuals",
     "You limited the conversation to the current participants" : "Avètz limitat la conversacion als participants actuals",
     "An administrator limited the conversation to the current participants" : "Un administrator a limitat la conversacion als participants actuals",
+    "You opened the conversation to registered users" : "Dobriretz la conversacion als utilizaires enregistrats",
+    "An administrator opened the conversation to registered users" : "Un administrator dobriguèt la conversacion als utilizaires enregistrats",
+    "{actor} opened the conversation to registered and guest app users" : "{actor} dobriguèt la conversacion als utilizaires enregistrats",
     "The conversation is now open to everyone" : "La conversacion es ara dubèrta a tot lo monde",
     "{actor} opened the conversation to everyone" : "{actor} a dubèrta la conversacion a tot lo monde",
     "You opened the conversation to everyone" : "Avètz dobèrta la conversacion a tot lo monde",
+    "{actor} allowed guests" : "{actor} autorizèt los convidats",
     "You allowed guests" : "Avètz autorizat los convidats",
+    "An administrator allowed guests" : "Un administrator autorizèt los convidats",
+    "{actor} disallowed guests" : "{actor} interdiguèt los convidats",
     "You disallowed guests" : "Avètz interdich los convidats",
     "An administrator disallowed guests" : "Un administrator desactivèt los convidats",
     "{actor} set a password" : "{actor} a definit un senhal",
@@ -76,6 +83,7 @@ OC.L10N.register(
     "You deleted a message" : "Avètz suprimit un messatge",
     "Message deleted by author" : "Messatge suprimit per son autor",
     "Message deleted by {actor}" : "Messatge suprimit per {actor}",
+    "Message deleted by you" : "Messatge suprimit per vos",
     "%s (guest)" : "%s (convidat)",
     "Call with {user1} and {user2} (Duration {duration})" : "Sonada amb {user1} e {user2} (Durada {duration})",
     "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Sonada amb {user1}, {user2} e {user3} (Durada {duration})",
@@ -83,11 +91,19 @@ OC.L10N.register(
     "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Sonada amb {user1}, {user2}, {user3}, {user4} e {user5} (Durada {duration})",
     "Talk to %s" : "Parlar a %s",
     "No account available to delete." : "Cap de compte pas disponible per la supression.",
+    "No image file provided" : "Cap de fichièr imatge provesit",
+    "File is too big" : "Fichièr tròp pesuc",
+    "Invalid file provided" : "Fichièr provesit invalid",
+    "Invalid image" : "Imatge invalid",
+    "Unknown filetype" : "filetype desconegut",
+    "An error occurred. Please contact your admin." : "Una error s’es producha. Contactatz l’administrator.",
     "Talk mentions" : "Mencions Talk",
     "Write to conversation" : "Escriure dins la conversacion",
     "%s invited you to a conversation." : "%s vos a convidat a una conversacion.",
     "You were invited to a conversation." : "Òm vos a convidat a una conversacion.",
     "Conversation invitation" : "Convit de conversacion",
+    "Click the button below to join." : "Clicatz sul boton per participar.",
+    "Join »%s«" : "Rejónher « %s »",
     "Meeting ID" : "Identificant reünion",
     "Your PIN" : "Vòstre còdi",
     "Password request: %s" : "Senhal requerit : %s",
@@ -95,6 +111,11 @@ OC.L10N.register(
     "Deleted user (%s)" : "Utilizaire suprimit (%s)",
     "{user} in {call}" : "{user} dins {call}",
     "Deleted user in {call}" : "Utilizaire suprimit dins {call}",
+    "{guest} (guest) in {call}" : "{guest} (guest) dins {call}",
+    "{user} sent you a private message" : "{user} vos a enviat un messatge privat",
+    "{user} sent a message in conversation {call}" : "{user} a enviat un messatge dins la conversacion {call}",
+    "A guest mentioned you in conversation {call}" : "Un convidat vos a mencionat dins la conversacion {call}",
+    "Join call" : "Rejónher la sonada",
     "Answer call" : "Respondre a l’apèl",
     "{user} would like to talk with you" : "{user} volriá vos parlar",
     "Call back" : "Tornar",
@@ -158,8 +179,11 @@ OC.L10N.register(
     "Colombia" : "Colombia",
     "Costa Rica" : "Còsta Rica",
     "Cuba" : "Cubà",
+    "Cabo Verde" : "Cap Verd",
+    "Curaçao" : "Curaçao",
     "Christmas Island" : "Illa Cristmas",
     "Cyprus" : "Chipre",
+    "Czechia" : "Republica Chèca",
     "Germany" : "Alemanha",
     "Djibouti" : "Jiboti",
     "Denmark" : "Danemarc",
@@ -199,6 +223,7 @@ OC.L10N.register(
     "Guinea-Bissau" : "Guinèa-Bissau",
     "Guyana" : "Guianà",
     "Hong Kong" : "Hong Kong",
+    "Heard Island and McDonald Islands" : "Illas de Heard e McDonald",
     "Honduras" : "Hondures",
     "Croatia" : "Croacia",
     "Haiti" : "Aïtí",
@@ -241,9 +266,12 @@ OC.L10N.register(
     "Libya" : "Libia",
     "Morocco" : "Marròc",
     "Monaco" : "Monegue",
+    "Moldova, Republic of" : "Moldàvia",
     "Montenegro" : "Montenegro",
+    "Saint Martin (French part)" : "Sant Martin (francés)",
     "Madagascar" : "Madagascar",
     "Marshall Islands" : "Illas Marshall",
+    "Macedonia, the former Yugoslav Republic of" : "Republica de Macedònia del Nòrd",
     "Mali" : "Mali",
     "Myanmar" : "Myanmar",
     "Mongolia" : "Mongolia",
@@ -282,6 +310,7 @@ OC.L10N.register(
     "Saint Pierre and Miquelon" : "Sant Pèire e Miquelon",
     "Pitcairn" : "Illas Pitcairn",
     "Puerto Rico" : "Puerto Rico",
+    "Palestine, State of" : "Estat de Palestina",
     "Portugal" : "Portugal",
     "Palau" : "Palau",
     "Paraguay" : "Paraguai",
@@ -331,6 +360,7 @@ OC.L10N.register(
     "Uruguay" : "Uruguai",
     "Uzbekistan" : "Ozbequistan",
     "Saint Vincent and the Grenadines" : "Sant Vincenç e las Grenadinas",
+    "Virgin Islands, British" : "Illas Verges Britanicas",
     "Virgin Islands, U.S." : "Virgin Islands, U.S.",
     "Viet Nam" : "Vinyes",
     "Vanuatu" : "Vanuatu",
@@ -341,13 +371,22 @@ OC.L10N.register(
     "South Africa" : "Sudafrica",
     "Zambia" : "Zambia",
     "Zimbabwe" : "Zimbabwe",
+    "Conversation not found" : "Conversacion pas trobada",
+    "Chat, video & audio-conferencing using WebRTC" : "Messatjariá, conferéncias vidèo e àudio amb WebRTC",
     "Leave call" : "Quitar la sonada",
+    "Stay in call" : "Demorar en linha",
+    "Duplicate session" : "Duplicar la session",
     "Discuss this file" : "Discutir d’aqueste fichièr",
     "Share this file" : "Partejar aqueste fichièr",
     "Join conversation" : "Rejónher la conversacion",
     "Request password" : "Demandar senhal",
+    "Error requesting the password." : "Error en demandant lo senhal.",
+    "This conversation has ended" : "La conversacion es acabada",
+    "Limit to groups" : "Limitar als grops",
     "Limit using Talk" : "Limits d’utilizacion de Talk",
     "Everyone" : "Tot lo monde",
+    "Users and moderators" : "Utilizaires e moderators",
+    "Moderators only" : "Moderators solament",
     "Save changes" : "Salvar los cambiaments",
     "Saving …" : "Enregistrament…",
     "Saved!" : "Enregistrat",
@@ -361,6 +400,8 @@ OC.L10N.register(
     "Script" : "Escript",
     "Response to" : "Respondre a",
     "General settings" : "Paramètres generals",
+    "Default notification settings" : "Paramètres de notificacion per defaut",
+    "Default group notification" : "Notificacion de grop per defaut",
     "All messages" : "Totes los messatges",
     "Off" : "Atudat",
     "URL of this Nextcloud instance" : "URL d’aquesta instància Nextcloud",
@@ -381,7 +422,9 @@ OC.L10N.register(
     "Installed version: {version}" : "Version installada : {version}",
     "An error occurred while installing the Talk Matterbridge. Please install it manually." : "Una error s’es producha pendent l’installacion de Talk Matterbridge. Volgatz l’installar manualament.",
     "SIP configuration" : "Configuracion SIP",
+    "Enable SIP configuration" : "Activar la configuracion SIP",
     "Shared secret" : "Secret partejat",
+    "Phone number (Country)" : "Numèro de telefòn (País)",
     "Validate SSL certificate" : "Validar lo certificat SSL",
     "Delete this server" : "Suprimir aqueste servidor",
     "Status: Checking connection" : "Estat : verificacion de la connexion",
@@ -399,14 +442,22 @@ OC.L10N.register(
     "TURN server protocols" : "Protocòls servidor TURN",
     "Test this server" : "Ensajar aqueste servidor",
     "TURN servers" : "Servidor TURN",
+    "Previous page of videos" : "Pagina de vidèos precedenta",
+    "Next page of videos" : "Pagina de vidèos seguenta",
     "Copy link" : "Copiar lo ligam",
+    "Connecting …" : "Connexion…",
     "Waiting for others to join the call …" : "En espèra que d’autres arriben…",
     "Share this link to invite others!" : "Partejatz aqueste ligam per convidar mai de monde !",
     "Conversation link copied to clipboard." : "Ligam de conversacion copiat al quichapapièrs.",
+    "Share whole screen" : "Partejar l’ecran complet",
+    "Share a single window" : "Partejar sonque una fenèstra",
+    "Show your screen" : "Partejar l’ecran",
     "Stop screensharing" : "Arrestar partiment d’ecran",
+    "Lower hand (r)" : "Baissar la man (r)",
     "More actions" : "Mai d’accions",
     "Settings" : "Paramètres",
     "Dismiss" : "Regetar",
+    "Raise hand (r)" : "Levar la man (r)",
     "No audio" : "Cap d’àudio",
     "Mute audio (m)" : "Copar lo son (m)",
     "Unmute audio (m)" : "Restablir lo son (m)",
@@ -419,26 +470,41 @@ OC.L10N.register(
     "Enable video" : "Activar la vidèo",
     "Screensharing options" : "Opcion de partiment d’ecran",
     "Enable screensharing" : "Activar lo partiment d’ecran",
+    "Bad sent video and screen quality." : "Marrida vidèo enviada e qualitat d’ecran.",
+    "Bad sent screen quality." : "Marrida qualitat d’ecran enviada.",
     "Disable screenshare" : "Desactivar lo partiment d’ecran",
+    "Screen sharing is not supported by your browser." : "Vòstre navegador pren pas en carga lo partiment d’ecran.",
+    "Screen sharing requires the page to be loaded through HTTPS." : "Lo partiment d’ecran requerís que la pagina siá cargada via HTTPS.",
     "Screensharing requires the page to be loaded through HTTPS." : "Lo partiment d’ecran requerís un cargament via HTTPS.",
     "Screensharing extension is required to share your screen." : "Una extension de partiment d’ecran es requerida per partejar l’ecran.",
     "An error occurred while starting screensharing." : "S’es producha una error en aviant lo partiment d’ecran.",
     "Back" : "Retorn",
+    "Access to camera was denied" : "L’accès a la camèra es estat refusat",
+    "Error while accessing camera" : "Error pendent l’accès a la camèra",
+    "You have been muted by a moderator" : "Un moderator vos a amudit",
+    "You" : "Vos",
     "Show screen" : "Far veire l’ecran",
     "Mute" : "Mut",
     "Stop following" : "Quitar de seguir",
+    "Conversation messages" : "Messatges de conversacion",
     "Post message" : "Publicar messatge",
     "This conversation is read-only" : "Aquesta conversacion es en lectura sola",
+    "Drop your files to upload" : "Depausatz los fichièrs d’enviar",
     "Call in progress" : "Sonada en cors",
     "Favorite" : "Favorit",
     "Conversation settings" : "Paramètres de conversacion",
     "Chat notifications" : "Notificacions de chat",
     "Guests access" : "Accès convidat",
     "Meeting settings" : "Paramètres de reünion",
+    "Matterbridge" : "Matterbridge",
+    "Danger zone" : "Zòna perilhosa",
+    "Be careful, these actions cannot be undone." : "Fasètz atencion, aquelas accions pòdon pas èsser anulladas.",
     "Leave conversation" : "Quitar la conversacion",
     "Delete conversation" : "Suprimir la conversacion",
     "Do you really want to delete \"{displayName}\"?" : "Volètz vertadièrament suprimir « {displayName} » ?",
+    "Error while deleting conversation" : "Error pendent la supression de la conversacion",
     "Allow guests" : "Autorizar los convidats",
+    "Set a password to restrict who can use the public link." : "Definir lo senhal per restrénher qual pòt utilizar lo ligam public.",
     "Password protection" : "Protegir via senhal",
     "Enter a password" : "Picatz un senhal",
     "Save password" : "Enregistrar lo senhal",
@@ -447,6 +513,8 @@ OC.L10N.register(
     "Invitations sent" : "Invitacions enviadas",
     "Enable lobby" : "Activar la sala d’espèra",
     "After the time limit the lobby will be automatically disabled." : "Aprèp la limita de temps la sala d’espèra serà automaticament desactivada.",
+    "Meeting start time" : "Ora de debuta de la conferéncia",
+    "Start time (optional)" : "Ora de debuta (opcional)",
     "Lock conversation" : "Verrolhar la conversacion",
     "Save" : "Salvar",
     "Edit" : "Modificar",
@@ -458,6 +526,8 @@ OC.L10N.register(
     "Talk conversation" : "Conversacion Talk",
     "Matrix server URL" : "URL servidor Matrix",
     "Matrix channel" : "Cadena Matrix",
+    "Mattermost server URL" : "URL servidor Mattermost",
+    "Mattermost user" : "Utilizaire Mattermost",
     "Team name" : "Nom de la còla",
     "Channel name" : "Nom de la cadena",
     "Password" : "Senhal",
@@ -479,8 +549,13 @@ OC.L10N.register(
     "Jabber ID" : "ID Jabber",
     "unknown state" : "estat desconegut",
     "running" : "en cors d'execucion",
+    "not running" : "pas en execucion",
+    "Conversation \"{conversationName}\"" : "Conversacion « {conversationName} »",
+    "Settings for conversation \"{conversationName}\"" : "Paramètres per la conversacion « {conversationName} »",
+    "Mark as read" : "Marcar coma legit",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
+    "Joining conversation …" : "Dintra dins la conversacion…",
     "You: {lastMessage}" : "Vos : {lastMessage}",
     "{actor}: {lastMessage}" : "{actor} : {lastMessage}",
     "No matches" : "Cap de resultat correspond pas",
@@ -492,6 +567,7 @@ OC.L10N.register(
     "Circles" : "Cercles",
     "Talk settings" : "Paramètres Talk",
     "Users and groups" : "Utilizaires e grops",
+    "Other sources" : "Autras fonts",
     "Creating your conversation" : "Creacion de vòstra conversacion",
     "Create a new group conversation" : "Crear una conversacion de grop novèla",
     "Password protect" : "Protegir per un senhal",
@@ -514,8 +590,12 @@ OC.L10N.register(
     "No camera available" : "Cap de camèra pas disponibla",
     "Select camera" : "Causir una camèra",
     "Reply" : "Respondre",
+    "Mark as unread" : "Marcar coma pas legit",
+    "Unread messages" : "Messatges pas legits",
     "Sending message" : "Mandadís del messatge",
     "Message sent" : "Messatge mandat",
+    "Not enough free space to upload file" : "Pas pro d’espaci liure per enviar lo fichièr",
+    "You can not send messages to this conversation at the moment" : "Podètz pas enviar de messatges a aquesta conversacion pel moment",
     "Deleting message" : "Supression del messatge",
     "Remove" : "Suprimir",
     "Today" : "Uèi",
@@ -526,6 +606,7 @@ OC.L10N.register(
     "File to share" : "Fichièr de partejar",
     "This conversation has been locked" : "Aquesta conversacion foguèt clavada",
     "Write message, @ to mention someone …" : "Escriure un messatge, @ per mencionar qualqu’un…",
+    "Cancel editing description" : "Anullar la modificacion de la descripcion",
     "Description" : "Descripcion",
     "Disable lobby" : "Desactivar la sala d’espèra",
     "moderator" : "moderator",
@@ -544,29 +625,43 @@ OC.L10N.register(
     "Add users or groups" : "Add users or groups",
     "Participants" : "Participants",
     "Search or add participants" : "Cercar o apondre participants",
+    "An error occurred while adding the participants" : "Una error s’es producha en ajustant los participants",
+    "An error occurred while fetching the participants" : "Una error s’es producha en recuperant los participants",
     "Add a description for this conversation" : "Apondre una descripcion per aquesta conversacion",
     "Chat" : "Messatjariá",
     "Details" : "Detalhs",
+    "Error while updating conversation description" : "Error pendent l’actualizacion de la descripcion de la conversacion",
     "Display name: " : "Nom d’afichatge :",
     "Choose devices" : "Causir periferics",
+    "Attachments folder" : "Dossièr de pèças-juntas",
     "Privacy" : "Confidencialitat",
+    "Sounds" : "Sons",
+    "Play sounds when participants join a call or leave it" : "Emetre sons quand los participants rejonhon o quitan una sonada",
     "Keyboard shortcuts" : "Acorchis de clavièr",
     "Speed up your Talk experience with these quick shortcuts." : "Acceleratz vòstra experiéncia Talk amb aqueles acorchis.",
+    "Fullscreen the chat or call" : "Passar la messatjariá o la sonada en plen ecran",
     "Search" : "Search",
     "Shortcuts while in a call" : "Acorchis pendent una sonada",
+    "Video on and off" : "Vidèo activada/desactivada",
+    "Microphone on and off" : "Microfòn activat/desactivat",
     "Push to talk or push to mute" : "Tocar per parlar o tocar per copar lo son",
+    "Select location for attachments" : "Causir un emplaçament per las pèças juntas",
     "Start call" : "Començar sonada",
     "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Nextcloud Talk foguèt mes a jorn, vos cal recargar la pagina abans de poder començar o participar a una sonada.",
+    "Conversation actions" : "Accions de conversacion",
     "Toggle fullscreen" : "Bascular en mòde ecran complet",
+    "Go to file" : "Anar al fichièr",
     "Rename conversation" : "Renomenar la conversacion",
     "Mute others" : "Copar lo son dels autres",
     "Exit fullscreen (f)" : "Sortir del ecran complèt (f)",
     "Fullscreen (f)" : "Ecran complèt (f)",
     "Grid view" : "Vista en grasilha",
     "Send" : "Mandar",
+    "Add more files" : "Apondre mai de fichièrs",
     "Start a conversation" : "Començar una conversacion",
     "You were mentioned" : "Qualqu’un vos a mencionat",
     "Message without mention" : "Messatge sens mencion",
+    "The conversation does not exist" : "La conversacion existís pas",
     "No conversations found" : "Cap de conversacion pas trobada",
     "Select conversation" : "Seleccionar una conversacion",
     "Link to a conversation" : "Ligam cap a la conversacion",
@@ -578,6 +673,8 @@ OC.L10N.register(
     "Nextcloud is in maintenance mode, please reload the page" : "Nextcloud es en mòde manteniment, volgatz recargar la pagina",
     "Error while sharing file" : "Error pendent lo partiment del fichièr",
     "Leave this page" : "Quitar aquesta pagina",
+    "Not enough free space to upload file \"{fileName}\"" : "Pas pro d’espaci liure per enviar lo fichièr « {fileName} »",
+    "Error while uploading file \"{fileName}\"" : "Error en enviant lo fichièr « {fileName} »",
     "Default" : "Defaut",
     "Microphone {number}" : "Microfòn {number}",
     "Camera {number}" : "Camèra {number}",
@@ -587,9 +684,12 @@ OC.L10N.register(
     "Please move your setup to HTTPS" : "Mercés de passar vòstra configuracion al HTTPS",
     "Access to microphone & camera was denied" : "L’accès al microfòn e a la camèra es estat refusat",
     "WebRTC is not supported in your browser" : "Vòstre navegador pren pas en carga lo WebRTC",
+    "Please use a different browser like Firefox or Chrome" : "Volgatz utilizar un navegador diferent coma Firefox o Chrome",
+    "Error while accessing microphone & camera" : "Error pendent l’accès al microfòn e a la camèra",
     "This conversation is password-protected" : "Aquesta conversacion es protegida per senhal",
     "The password is wrong. Try again." : "Lo senhal es incorrècte. Ensajatz tornamai.",
     "TURN server" : "Servidor TURN",
+    "Signaling servers" : "Servidors de senhalizacion",
     "%s Talk on your mobile devices" : "%sTalk on vòstres aparelhs mobiles",
     "Android app" : "Aplicacion Android",
     "iOS app" : "Aplicacion iOS",
@@ -598,18 +698,27 @@ OC.L10N.register(
     "New in Talk 8" : "Nòu dins Talk 8",
     "New in Talk 9" : "Nòu dins Talk 9",
     "{user} wants to talk with you" : "{user} vòl vos parlar",
+    "Signaling server URL" : "URL del servidor de senhalizacion",
     "UDP and TCP" : "UDP e TCP",
     "UDP only" : "Sonque UDP",
     "TCP only" : "Sonque TCP",
+    "This conversation is read only" : "La conversacion es en lectura sola",
     "Conversation, " : "Conversacion, ",
+    "Default location for attachments" : "Emplaçament per defaut per las pèças juntas",
+    "Select default location for attachments" : "Causir un emplaçament per defaut per las pèças juntas",
     "Allow guests to join via link " : "Permetre als convidats de rejónher via ligam",
+    "Participant settings" : "Paramètres participants",
     "Add participants to the conversation" : "Apondre participants a la conversacion",
     "Projects" : "Projèctes",
     "Nextcloud Talk was updated, you need to reload the page before you can start or join a call" : "Nextcloud Talk foguèt mes a jorn, vos cal recargar la pagina abans de poder començar o participar a una sonada",
     "Share link" : "Partejar lo ligam",
     "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome or Apple Safari." : "Lo navegador qu’utilizatz es pas complètament pres en cargar per Nextcloud Talk. Mercés d’utilizar la darrièra version de Mozilla Firefox, Microsoft Edge, Google Chrome o Apple Safari.",
+    "Error while uploading file" : "Error en enviant lo fichièr",
     "New in Talk 10" : "Nòu dins Talk 10",
+    "E-mail of the user" : "E-mail de l’utilizaire",
     "Enabled" : "Activada",
+    "Lower hand" : "Baissar la man",
+    "Raise hand" : "Levar la man",
     "turn: and turns:" : "turn: e turns:",
     "turn: only" : "turn: sonque",
     "turns: only" : "turns: sonque"
