@@ -113,7 +113,7 @@ class MatterbridgeManager {
 	 * @return array process state and log
 	 */
 	public function getBridgeProcessState(Room $room): array {
-		$bridge =  $this->getBridgeFromDb($room);
+		$bridge = $this->getBridgeFromDb($room);
 
 		$logContent = $this->getBridgeLog($room);
 
@@ -160,8 +160,7 @@ class MatterbridgeManager {
 
 		$this->notify($room, $userId, $currentBridge, $newBridge);
 
-		// edit/update the config file
-		$this->editBridgeConfig($room, $newBridge);
+		$this->writeBridgeConfig($room, $newBridge);
 
 		// check state and manage the binary
 		$pid = $this->checkBridgeProcess($room, $newBridge);
@@ -238,13 +237,13 @@ class MatterbridgeManager {
 	}
 
 	/**
-	 * Edit the mattermost configuration file for one room
+	 * Write the mattermost configuration file for one room
 	 * This method takes care of connecting the bridge to the Talk room with a bot user
 	 *
 	 * @param Room $room
 	 * @param array $newBridge
 	 */
-	private function editBridgeConfig(Room $room, array $newBridge): void {
+	private function writeBridgeConfig(Room $room, array $newBridge): void {
 		// check bot user exists and is member of the room
 		// add the 'local' bridge part
 		$newBridge = $this->addLocalPart($room, $newBridge);
@@ -281,10 +280,10 @@ class MatterbridgeManager {
 	 * and to generate a new app token (used to connect via matterbridge)
 	 *
 	 * @param Room $room the room
-	 * @param bool $create whether we should generate a new app token or not
+	 * @param bool $isBridgeEnabled whether we should add the bot and generate a new app token or remove the bot from the room
 	 * @return array Bot user information (username and app token). token is an empty string if creation was not asked.
 	 */
-	private function checkBotUser(Room $room, bool $create): array {
+	private function checkBotUser(Room $room, bool $isBridgeEnabled): array {
 		$botUserId = 'bridge-bot';
 		// check if user exists and create it if necessary
 		if (!$this->userManager->userExists($botUserId)) {
@@ -299,15 +298,20 @@ class MatterbridgeManager {
 			$botUser = $this->userManager->get($botUserId);
 		}
 
-		// check user is member of the room
+		// check if the bot user is member of the room and add or remove it
 		try {
 			$participant = $room->getParticipant($botUserId);
+			if (!$isBridgeEnabled) {
+				$this->participantService->removeUser($room, $botUser, Room::PARTICIPANT_REMOVED);
+			}
 		} catch (ParticipantNotFoundException $e) {
-			$this->participantService->addUsers($room, [[
-				'actorType' => Attendee::ACTOR_USERS,
-				'actorId' => $botUserId,
-				'participantType' => Participant::USER,
-			]]);
+			if ($isBridgeEnabled) {
+				$this->participantService->addUsers($room, [[
+					'actorType' => Attendee::ACTOR_USERS,
+					'actorId' => $botUserId,
+					'participantType' => Participant::USER,
+				]]);
+			}
 		}
 
 		// delete old bot app tokens for this room
@@ -319,7 +323,7 @@ class MatterbridgeManager {
 			}
 		}
 
-		if ($create) {
+		if ($isBridgeEnabled) {
 			// generate app token for the bot
 			$appToken = $this->generatePassword();
 			$botPassword = $this->config->getAppValue('spreed', 'bridge_bot_password', '');
@@ -461,10 +465,13 @@ class MatterbridgeManager {
 				}
 				$content .= sprintf('[%s.%s]', $type, $k) . "\n";
 				$content .= sprintf('	Server = "%s"', $part['server']) . "\n";
+				if ($part['password']) {
+					$content .= sprintf('	Password = "%s"', $part['password']) . "\n";
+				}
 				$content .= sprintf('	Nick = "%s"', $part['nick']) . "\n";
 				if ($part['nickservnick']) {
 					$content .= sprintf('	NickServNick = "%s"', $part['nickservnick']) . "\n";
-					$content .= sprintf('	NickServNick = "%s"', $part['nickservnick']) . "\n";
+					$content .= sprintf('	NickServPassword = "%s"', $part['nickservpassword']) . "\n";
 				}
 				if ($part['usetls']) {
 					$content .= sprintf('	UseTLS = true') . "\n";
@@ -506,8 +513,8 @@ class MatterbridgeManager {
 			$content .= '[[gateway.inout]]' . "\n";
 			$content .= sprintf('	account = "%s.%s"', $type, $k) . "\n";
 			$content .= sprintf('	channel = "%s"', $part['channel']) . "\n";
-			if ($type === 'irc' && $part['password']) {
-				$content .= sprintf('	options = { key = "%s" }', $part['password']) . "\n";
+			if ($type === 'irc' && $part['channelpassword']) {
+				$content .= sprintf('	options = { key = "%s" }', $part['channelpassword']) . "\n";
 			}
 			$content .= "\n";
 		}
@@ -598,11 +605,15 @@ class MatterbridgeManager {
 	private function notify(Room $room, string $userId, array $currentBridge, array $newBridge): void {
 		$currentParts = $currentBridge['parts'];
 		$newParts = $newBridge['parts'];
-		if (empty($currentParts) && !empty($newParts)) {
+		if ($currentBridge['enabled'] && !$newBridge['enabled']) {
+			$this->sendSystemMessage($room, $userId, 'matterbridge_config_disabled');
+		} elseif (!$currentBridge['enabled'] && $newBridge['enabled']) {
+			$this->sendSystemMessage($room, $userId, 'matterbridge_config_enabled');
+		} elseif (empty($currentParts) && !empty($newParts)) {
 			$this->sendSystemMessage($room, $userId, 'matterbridge_config_added');
 		} elseif (!empty($currentParts) && empty($newParts)) {
 			$this->sendSystemMessage($room, $userId, 'matterbridge_config_removed');
-		} elseif (empty($currentParts) !== empty($newParts) || !$this->compareBridges($currentBridge, $newBridge)) {
+		} elseif (count($currentParts) !== count($newParts) || !$this->compareBridges($currentBridge, $newBridge)) {
 			$this->sendSystemMessage($room, $userId, 'matterbridge_config_edited');
 		}
 	}
@@ -680,6 +691,13 @@ class MatterbridgeManager {
 	private function launchMatterbridge(Room $room): int {
 		$binaryPath = $this->config->getAppValue('spreed', 'matterbridge_binary');
 		$configPath = sprintf('/tmp/bridge-%s.toml', $room->getToken());
+
+		// recreate config file if it's not there (can happen after a reboot)
+		if (!file_exists($configPath)) {
+			$currentBridge = $this->getBridgeOfRoom($room);
+			$this->writeBridgeConfig($room, $currentBridge);
+		}
+
 		$outputPath = sprintf('/tmp/bridge-%s.log', $room->getToken());
 		$matterbridgeCmd = sprintf('%s -conf %s', $binaryPath, $configPath);
 		$cmd = sprintf('nice -n19 %s > %s 2>&1 & echo $!', $matterbridgeCmd, $outputPath);
