@@ -37,6 +37,7 @@ use OCA\Talk\Exceptions\ParticipantNotFoundException;
 use OCA\Talk\Exceptions\UnauthorizedException;
 use OCA\Talk\Model\Attendee;
 use OCA\Talk\Model\AttendeeMapper;
+use OCA\Talk\Model\SelectHelper;
 use OCA\Talk\Model\Session;
 use OCA\Talk\Model\SessionMapper;
 use OCA\Talk\Participant;
@@ -47,12 +48,16 @@ use OCP\AppFramework\Utility\ITimeFactory;
 use OCP\Comments\IComment;
 use OCP\DB\QueryBuilder\IQueryBuilder;
 use OCP\EventDispatcher\IEventDispatcher;
+use OCP\IConfig;
 use OCP\IDBConnection;
 use OCP\IUser;
 use OCP\IUserManager;
+use OCP\IGroupManager;
 use OCP\Security\ISecureRandom;
 
 class ParticipantService {
+	/** @var IConfig */
+	protected $serverConfig;
 	/** @var Config */
 	protected $talkConfig;
 	/** @var AttendeeMapper */
@@ -69,10 +74,13 @@ class ParticipantService {
 	private $dispatcher;
 	/** @var IUserManager */
 	private $userManager;
+	/** @var IGroupManager */
+	private $groupManager;
 	/** @var ITimeFactory */
 	private $timeFactory;
 
-	public function __construct(Config $talkConfig,
+	public function __construct(IConfig $serverConfig,
+								Config $talkConfig,
 								AttendeeMapper $attendeeMapper,
 								SessionMapper $sessionMapper,
 								SessionService $sessionService,
@@ -80,7 +88,9 @@ class ParticipantService {
 								IDBConnection $connection,
 								IEventDispatcher $dispatcher,
 								IUserManager $userManager,
+								IGroupManager $groupManager,
 								ITimeFactory $timeFactory) {
+		$this->serverConfig = $serverConfig;
 		$this->talkConfig = $talkConfig;
 		$this->attendeeMapper = $attendeeMapper;
 		$this->sessionMapper = $sessionMapper;
@@ -89,6 +99,7 @@ class ParticipantService {
 		$this->connection = $connection;
 		$this->dispatcher = $dispatcher;
 		$this->userManager = $userManager;
+		$this->groupManager = $groupManager;
 		$this->timeFactory = $timeFactory;
 	}
 
@@ -161,12 +172,30 @@ class ParticipantService {
 				throw new InvalidPasswordException('Provided password is invalid');
 			}
 
-			// User joining a public room, without being invited
-			$this->addUsers($room, [[
-				'actorType' => Attendee::ACTOR_USERS,
-				'actorId' => $user->getUID(),
-				'participantType' => Participant::USER_SELF_JOINED,
-			]]);
+			// queried here to avoid loop deps
+			$manager = \OC::$server->get(\OCA\Talk\Manager::class);
+
+			// User joining a group or public call through listing
+			if (($room->getType() === Room::GROUP_CALL || $room->getType() === Room::PUBLIC_CALL) &&
+				$manager->isRoomListableByUser($room, $user->getUID())
+			) {
+				$this->addUsers($room, [[
+					'actorType' => Attendee::ACTOR_USERS,
+					'actorId' => $user->getUID(),
+					// need to use "USER" here, because "USER_SELF_JOINED" only works for public calls
+					'participantType' => Participant::USER,
+				]]);
+			} elseif ($room->getType() === Room::PUBLIC_CALL) {
+				// User joining a public room, without being invited
+				$this->addUsers($room, [[
+					'actorType' => Attendee::ACTOR_USERS,
+					'actorId' => $user->getUID(),
+					'participantType' => Participant::USER_SELF_JOINED,
+				]]);
+			} else {
+				// shouldn't happen unless some code called joinRoom without previous checks
+				throw new UnauthorizedException('Participant is not allowed to join');
+			}
 
 			$attendee = $this->attendeeMapper->findByActor($room->getId(), Attendee::ACTOR_USERS, $user->getUID());
 		}
@@ -238,12 +267,18 @@ class ParticipantService {
 		}
 
 		foreach ($participants as $participant) {
+			$readPrivacy = Participant::PRIVACY_PUBLIC;
+			if ($participant['actorType'] === Attendee::ACTOR_USERS) {
+				$readPrivacy = $this->talkConfig->getUserReadPrivacy($participant['actorId']);
+			}
+
 			$attendee = new Attendee();
 			$attendee->setRoomId($room->getId());
 			$attendee->setActorType($participant['actorType']);
 			$attendee->setActorId($participant['actorId']);
 			$attendee->setParticipantType($participant['participantType'] ?? Participant::USER);
 			$attendee->setLastReadMessage($lastMessage);
+			$attendee->setReadPrivacy($readPrivacy);
 			$this->attendeeMapper->insert($attendee);
 		}
 
@@ -283,7 +318,7 @@ class ParticipantService {
 		$attendee = $participant->getAttendee();
 		if ($room->getSIPEnabled() === Webinary::SIP_ENABLED
 			&& $this->talkConfig->isSIPConfigured()
-			&& $attendee->getActorType() === Attendee::ACTOR_USERS
+			&& ($attendee->getActorType() === Attendee::ACTOR_USERS || $attendee->getActorType() === Attendee::ACTOR_EMAILS)
 			&& !$attendee->getPin()) {
 			$attendee->setPin($this->generatePin());
 			$this->attendeeMapper->update($attendee);
@@ -413,8 +448,9 @@ class ParticipantService {
 		$this->sessionService->deleteSessionsById($sessionTableIds);
 
 		$query = $this->connection->getQueryBuilder();
-		$query->selectAlias('a.id', 'a_id')
-			->from('talk_attendees', 'a')
+		$helper = new SelectHelper();
+		$helper->selectAttendeesTable($query);
+		$query->from('talk_attendees', 'a')
 			->leftJoin('a', 'talk_sessions', 's', $query->expr()->eq('s.attendee_id', 'a.id'))
 			->where($query->expr()->eq('a.room_id', $query->createNamedParameter($room->getId(), IQueryBuilder::PARAM_INT)))
 			->andWhere($query->expr()->eq('a.actor_type', $query->createNamedParameter(Attendee::ACTOR_GUESTS)))
@@ -471,6 +507,55 @@ class ParticipantService {
 		$query->execute();
 	}
 
+	public function updateReadPrivacyForActor(string $actorType, string $actorId, int $readPrivacy): void {
+		$query = $this->connection->getQueryBuilder();
+		$query->update('talk_attendees')
+			->set('read_privacy', $query->createNamedParameter($readPrivacy, IQueryBuilder::PARAM_INT))
+			->where($query->expr()->eq('actor_type', $query->createNamedParameter($actorType)))
+			->andWhere($query->expr()->eq('actor_id', $query->createNamedParameter($actorId)));
+		$query->execute();
+	}
+
+	public function getLastCommonReadChatMessage(Room $room): int {
+		$query = $this->connection->getQueryBuilder();
+		$query->selectAlias($query->func()->min('last_read_message'), 'last_common_read_message')
+			->from('talk_attendees')
+			->where($query->expr()->eq('actor_type', $query->createNamedParameter(Attendee::ACTOR_USERS)))
+			->andWhere($query->expr()->eq('room_id', $query->createNamedParameter($room->getId(), IQueryBuilder::PARAM_INT)))
+			->andWhere($query->expr()->eq('read_privacy', $query->createNamedParameter(Participant::PRIVACY_PUBLIC, IQueryBuilder::PARAM_INT)));
+
+		$result = $query->execute();
+		$row = $result->fetch();
+		$result->closeCursor();
+
+		return (int) ($row['last_common_read_message'] ?? 0);
+	}
+
+	/**
+	 * @param int[] $roomIds
+	 * @return array A map of roomId => "last common read message id"
+	 * @psalm-return  array<int, int>
+	 */
+	public function getLastCommonReadChatMessageForMultipleRooms(array $roomIds): array {
+		$query = $this->connection->getQueryBuilder();
+		$query->select('room_id')
+			->selectAlias($query->func()->min('last_read_message'), 'last_common_read_message')
+			->from('talk_attendees')
+			->where($query->expr()->eq('actor_type', $query->createNamedParameter(Attendee::ACTOR_USERS)))
+			->andWhere($query->expr()->in('room_id', $query->createNamedParameter($roomIds, IQueryBuilder::PARAM_INT_ARRAY)))
+			->andWhere($query->expr()->eq('read_privacy', $query->createNamedParameter(Participant::PRIVACY_PUBLIC, IQueryBuilder::PARAM_INT)))
+			->groupBy('room_id');
+
+		$commonReads = array_fill_keys($roomIds, 0);
+		$result = $query->execute();
+		while ($row = $result->fetch()) {
+			$commonReads[(int) $row['room_id']] = (int) $row['last_common_read_message'];
+		}
+		$result->closeCursor();
+
+		return $commonReads;
+	}
+
 	/**
 	 * @param Room $room
 	 * @return Participant[]
@@ -478,11 +563,10 @@ class ParticipantService {
 	public function getParticipantsForRoom(Room $room): array {
 		$query = $this->connection->getQueryBuilder();
 
-		$query->select('a.*')
-			->selectAlias('a.id', 'a_id')
-			->addSelect('s.*')
-			->selectAlias('s.id', 's_id')
-			->from('talk_attendees', 'a')
+		$helper = new SelectHelper();
+		$helper->selectAttendeesTable($query);
+		$helper->selectSessionsTable($query);
+		$query->from('talk_attendees', 'a')
 			->leftJoin(
 				'a', 'talk_sessions', 's',
 				$query->expr()->eq('s.attendee_id', 'a.id')
@@ -499,11 +583,10 @@ class ParticipantService {
 	public function getParticipantsWithSession(Room $room): array {
 		$query = $this->connection->getQueryBuilder();
 
-		$query->select('a.*')
-			->selectAlias('a.id', 'a_id')
-			->addSelect('s.*')
-			->selectAlias('s.id', 's_id')
-			->from('talk_attendees', 'a')
+		$helper = new SelectHelper();
+		$helper->selectAttendeesTable($query);
+		$helper->selectSessionsTable($query);
+		$query->from('talk_attendees', 'a')
 			->leftJoin(
 				'a', 'talk_sessions', 's',
 				$query->expr()->eq('s.attendee_id', 'a.id')
@@ -521,11 +604,10 @@ class ParticipantService {
 	public function getParticipantsInCall(Room $room): array {
 		$query = $this->connection->getQueryBuilder();
 
-		$query->select('a.*')
-			->selectAlias('a.id', 'a_id')
-			->addSelect('s.*')
-			->selectAlias('s.id', 's_id')
-			->from('talk_sessions', 's')
+		$helper = new SelectHelper();
+		$helper->selectAttendeesTable($query);
+		$helper->selectSessionsTable($query);
+		$query->from('talk_sessions', 's')
 			->leftJoin(
 				's', 'talk_attendees', 'a',
 				$query->expr()->eq('s.attendee_id', 'a.id')
@@ -544,11 +626,10 @@ class ParticipantService {
 	public function getParticipantsByNotificationLevel(Room $room, int $notificationLevel): array {
 		$query = $this->connection->getQueryBuilder();
 
-		$query->select('a.*')
-			->selectAlias('a.id', 'a_id')
-			->addSelect('s.*')
-			->selectAlias('s.id', 's_id')
-			->from('talk_attendees', 'a')
+		$helper = new SelectHelper();
+		$helper->selectAttendeesTable($query);
+		$helper->selectSessionsTable($query);
+		$query->from('talk_attendees', 'a')
 			->leftJoin(
 				'a', 'talk_sessions', 's',
 				$query->expr()->eq('s.attendee_id', 'a.id')
